@@ -15,21 +15,21 @@ import matplotlib
 # comment out the following to use wx rather than wxagg
 matplotlib.use('WXAgg')
 from matplotlib.backends.backend_wxagg import FigureCanvasWxAgg as FigureCanvas
-from matplotlib.backends.backend_wx import NavigationToolbar2Wx
+from matplotlib.backends.backend_wxagg import NavigationToolbar2WxAgg 
 
 from matplotlib.backends.backend_wx import _load_bitmap
 from matplotlib.figure import Figure
-from matplotlib.mlab import rand
+from matplotlib.numerix.mlab import rand
 
 from wxPython.wx import *
 
-class MyNavigationToolbar(NavigationToolbar2Wx):
+class MyNavigationToolbar(NavigationToolbar2WxAgg):
     """
     Extend the default wx toolbar with your own event handlers
     """
     ON_CUSTOM = wxNewId()
     def __init__(self, canvas, cankill):
-        NavigationToolbar2Wx.__init__(self, canvas)
+        NavigationToolbar2WxAgg.__init__(self, canvas)
 
         # for simplicity I'm going to reuse a bitmap from wx, you'll
         # probably want to add your own.
